package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchReqInfoSummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchReqInfoForDebts.class */
public class BatchReqInfoForDebts implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public BatchReqInfoForDebts() {
    }

    public BatchReqInfoForDebts(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BatchReqInfoSummary result = new BatchReqInfoSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                if (sheet.getRow(0).getPhysicalNumberOfCells() != 18) {
                    throw new TranFailException("excelError", "文件有误，与模板不一致");
                }
                int rowIndex = 2;
                HSSFRow recordRowTemp = sheet.getRow(2);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "文件内容为空");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                if (0 == 1) {
                    throw new TranFailException("excelError", "文件有误，与模板不一致");
                }
                if (0 == 2) {
                    throw new TranFailException("excelError", "文件内容为空");
                }
                throw FileConstants.EXCEPTION_PARSE_FAIL;
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v350, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v351, types: [com.ynet.life.exception.TranFailException] */
    /* JADX WARN: Type inference failed for: r0v352, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v44, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v45 */
    /* JADX WARN: Type inference failed for: r0v46, types: [com.ynet.life.exception.TranFailException] */
    /* JADX WARN: Type inference failed for: r0v48, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v49, types: [java.sql.SQLException] */
    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String cellContent = getCellContent(recordRow, 0, true);
        String corName = cellContent;
        if (!StringUtils.isEmpty(cellContent)) {
            corName = corName.replace("(", "（").replace(")", "）");
        }
        String orgCode = getCellContent(recordRow, 1, true);
        String pubTime = getCellContent(recordRow, 2, true);
        String financeName = getCellContent(recordRow, 3, true);
        String productName = getCellContent(recordRow, 4, true);
        String financeAmt = getCellContent(recordRow, 5, true);
        String financeTime = getCellContent(recordRow, 6, true);
        String beginrate = getCellContent(recordRow, 7, true);
        String endrate = getCellContent(recordRow, 8, true);
        String guaType = getCellContent(recordRow, 9, true);
        String financePurpose = getCellContent(recordRow, 10, true);
        String corContactName = getCellContent(recordRow, 11, true);
        String corContactTel = getCellContent(recordRow, 12, true);
        String busincomeofpreyear = getCellContent(recordRow, 13, true);
        String salesrevenue = getCellContent(recordRow, 14, true);
        String openFlag = getCellContent(recordRow, 15, true);
        String financeStation = getCellContent(recordRow, 16, true);
        String remark = getCellContent(recordRow, 17, true);
        Connection connection = null;
        String corNo = "";
        String financeId = "";
        String financeClassNo = "";
        String prdFlowNo = "";
        int count = 0;
        ?? r0 = "";
        String fprGuatype = "";
        try {
            try {
                Connection connection2 = LifeDBAccess.getConnection();
                connection = connection2;
                ResultSet resultSet1 = connection2.prepareStatement("SELECT count(1) FROM fsp_cor_inf_szyq WHERE PCI_ORGCODE='" + orgCode + "'").executeQuery();
                while (resultSet1.next()) {
                    count = resultSet1.getInt(1);
                }
                if (count == 1) {
                    ResultSet resultSet3 = connection.prepareStatement("SELECT FCI_CORNO FROM fsp_cor_inf_szyq WHERE PCI_ORGCODE='" + orgCode + "'").executeQuery();
                    while (resultSet3.next()) {
                        corNo = resultSet3.getString(1);
                    }
                } else {
                    ResultSet resultSet2 = connection.prepareStatement("SELECT count(1) FROM fsp_cor_inf_szyq WHERE PCI_NAMECN='" + corName + "' AND (PCI_ORGCODE IS null or PCI_ORGCODE ='')").executeQuery();
                    while (resultSet2.next()) {
                        count = resultSet2.getInt(1);
                    }
                    if (count == 1) {
                        ResultSet resultSet4 = connection.prepareStatement("SELECT FCI_CORNO FROM fsp_cor_inf_szyq WHERE PCI_NAMECN='" + corName + "' AND (PCI_ORGCODE IS null or PCI_ORGCODE ='')").executeQuery();
                        while (resultSet4.next()) {
                            corNo = resultSet4.getString(1);
                        }
                    }
                }
                ResultSet resultSet5 = connection.prepareStatement("SELECT FCB_FINANCEID,FCB_FINANCECLASSNO FROM fsp_cor_branch_szyq WHERE FCB_STT='0' AND FCB_NAME='" + financeName + "'").executeQuery();
                while (resultSet5.next()) {
                    financeId = resultSet5.getString(1);
                    financeClassNo = resultSet5.getString(2);
                    ResultSet resultSet6 = connection.prepareStatement("SELECT FPR_FLOWNO FROM fsp_finance_product_szyq WHERE FPR_STT = '2' AND FPR_PRONAME='" + productName + "' AND FPR_FINANCEID='" + financeId + "'").executeQuery();
                    if (resultSet6.next()) {
                        prdFlowNo = resultSet6.getString(1);
                    }
                }
                ResultSet resultSet7 = connection.prepareStatement("SELECT `CODE` FROM data_dictionary WHERE `NAME`='" + guaType + "' AND CATEGORY='3'").executeQuery();
                while (true) {
                    r0 = resultSet7.next();
                    if (r0 == 0) {
                        break;
                    }
                    fprGuatype = resultSet7.getString(1);
                }
            } catch (SQLException e) {
                r0.printStackTrace();
                Connection connection3 = connection;
                try {
                    LifeDBAccess.releaseConnection(connection3);
                } catch (TranFailException e2) {
                    connection3.printStackTrace();
                }
            }
            String dirFlag = "";
            String didRemark = "";
            if ("".equals(orgCode) || orgCode == null) {
                didRemark = String.valueOf(didRemark) + " 三证合一证为空";
            }
            if ("".equals(corName) || corName == null) {
                didRemark = String.valueOf(didRemark) + " 企业名称为空";
            }
            if (count > 1) {
                didRemark = String.valueOf(didRemark) + " 三证合一证不存在并且相同企业名称存在多个";
            } else if (count == 0 && orgCode.length() > 0 && corName.length() > 0) {
                didRemark = String.valueOf(didRemark) + " 该企业不存在";
            }
            if ("".equals(financeName) || financeName == null) {
                if ("".equals(productName) || productName == null) {
                    dirFlag = "0";
                } else {
                    didRemark = String.valueOf(didRemark) + " 申请产品时金融机构必输";
                }
            } else if ("".equals(financeId) || financeId == null) {
                didRemark = String.valueOf(didRemark) + " 平台内没有此金融机构或当前金融机构未启用";
            } else if ("".equals(productName) || productName == null) {
                dirFlag = "1";
            } else if (("".equals(prdFlowNo) || prdFlowNo == null) && !"".equals(financeName) && financeName != null) {
                didRemark = String.valueOf(didRemark) + " 此金融机构没有这个金融产品或当前产品未上架";
            } else {
                dirFlag = "1";
            }
            if ("".equals(guaType) || guaType == null) {
                didRemark = String.valueOf(didRemark) + " 担保方式为空";
            } else if ("".equals(fprGuatype) || fprGuatype == null) {
                didRemark = String.valueOf(didRemark) + " 请输入正确的担保方式";
            }
            if ("".equals(financeAmt) || financeAmt == null) {
                didRemark = String.valueOf(didRemark) + " 融资金额为空";
            } else if (!Pattern.compile("^[1-9]{1}\\d{0,7}$").matcher(financeAmt).matches()) {
                didRemark = String.valueOf(didRemark) + " 融资金额不符合规则";
            }
            if ("".equals(financeTime) || financeTime == null) {
                didRemark = String.valueOf(didRemark) + " 融资期限为空";
            } else if (!Pattern.compile("^[1-9]{1}\\d{0,2}$").matcher(financeTime).matches()) {
                didRemark = String.valueOf(didRemark) + " 融资期限不符合规则";
            } else if (Integer.parseInt(financeTime) > 360) {
                didRemark = String.valueOf(didRemark) + " 融资期限不能大于360";
            }
            if ("".equals(beginrate) || beginrate == null) {
                didRemark = String.valueOf(didRemark) + " 利率范围下限为空";
            } else if (!Pattern.compile("^\\d{1,3}(\\.\\d{1,2})?$").matcher(beginrate).matches()) {
                didRemark = String.valueOf(didRemark) + " 利率范围下限不符合规则";
            }
            if ("".equals(endrate) || endrate == null) {
                didRemark = String.valueOf(didRemark) + " 利率范围上限为空";
            } else if (!Pattern.compile("^\\d{1,3}(\\.\\d{1,2})?$").matcher(endrate).matches()) {
                didRemark = String.valueOf(didRemark) + " 利率范围上限不符合规则";
            } else if (Float.parseFloat(beginrate) > Float.parseFloat(endrate)) {
                didRemark = String.valueOf(didRemark) + " 利率范围下限大于利率范围上限";
            }
            if ("".equals(financePurpose) || financePurpose == null) {
                didRemark = String.valueOf(didRemark) + " 融资用途为空";
            }
            if ("".equals(corContactName) || corContactName == null) {
                didRemark = String.valueOf(didRemark) + " 联系人为空";
            } else if (!Pattern.compile("^([A-Za-z一-龥]){1,20}$").matcher(corContactName).matches()) {
                didRemark = String.valueOf(didRemark) + " 联系姓名不符合规则";
            }
            if ("".equals(corContactTel) || corContactTel == null) {
                didRemark = String.valueOf(didRemark) + " 联系人电话为空";
            } else if (!Pattern.compile("^((0\\d{2,3}-\\d{7,8})|(1[0-9]{10})|(\\d{8}))$").matcher(corContactTel).matches()) {
                didRemark = String.valueOf(didRemark) + " 联系电话不符合规则";
            }
            if ("".equals(busincomeofpreyear) || busincomeofpreyear == null) {
                didRemark = String.valueOf(didRemark) + " 上一年度销售收入为空";
            } else if (!Pattern.compile("^[1-9]{1}\\d{0,7}$").matcher(busincomeofpreyear).matches()) {
                didRemark = String.valueOf(didRemark) + " 上一年度销售收入不符合规则";
            }
            if ("".equals(salesrevenue) || salesrevenue == null) {
                didRemark = String.valueOf(didRemark) + " 本年度销售收入为空";
            } else if (!Pattern.compile("^[1-9]{1}\\d{0,7}$").matcher(salesrevenue).matches()) {
                didRemark = String.valueOf(didRemark) + " 本年度销售收入不符合规则";
            }
            if (!"".equals(openFlag) && openFlag != null && !"是".equals(openFlag) && !"否".equals(openFlag)) {
                didRemark = String.valueOf(didRemark) + " 是否公开字段只能为空或者是或者否";
            }
            if ("".equals(pubTime) || pubTime == null) {
                didRemark = String.valueOf(didRemark) + " 发布日期为空";
            } else if (pubTime.length() == 8) {
                SimpleDateFormat format = new SimpleDateFormat("yyyyMMdd");
                try {
                    format.setLenient(false);
                    format.parse(pubTime);
                } catch (ParseException unused) {
                    didRemark = String.valueOf(didRemark) + " 日期格式不正确";
                }
            } else {
                didRemark = String.valueOf(didRemark) + " 日期格式不正确";
            }
            result.put("corNo", corNo);
            result.put("financeId", financeId);
            result.put("financeClassNo", financeClassNo);
            result.put("prdFlowNo", prdFlowNo);
            result.put("dirFlag", dirFlag);
            result.put("corName", corName);
            result.put("orgCode", orgCode);
            result.put("pubTime", pubTime);
            result.put("financeName", financeName);
            result.put("productName", productName);
            result.put("financeAmt", financeAmt);
            result.put("financeTime", financeTime);
            result.put("beginrate", beginrate);
            result.put("endrate", endrate);
            result.put("guaType", guaType);
            result.put("fprGuatype", fprGuatype);
            result.put("financePurpose", financePurpose);
            result.put("corContactName", corContactName);
            result.put("corContactTel", corContactTel);
            result.put("busincomeofpreyear", busincomeofpreyear);
            result.put("salesrevenue", salesrevenue);
            result.put("openFlag", openFlag);
            result.put("financeStation", financeStation);
            result.put("remark", remark);
            result.put("didRemark", didRemark);
            return result;
        } finally {
            try {
                r0 = connection;
                LifeDBAccess.releaseConnection((Connection) r0);
            } catch (TranFailException e3) {
                r0.printStackTrace();
            }
        }
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell != null) {
                switch (cell.getCellType()) {
                    case 0:
                        String format = "######.##";
                        if (toInt) {
                            format = "#######";
                        }
                        if (HSSFDateUtil.isCellDateFormatted(cell)) {
                            result = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(HSSFDateUtil.getJavaDate(cell.getNumericCellValue()));
                            break;
                        } else {
                            result = new DecimalFormat(format).format(cell.getNumericCellValue());
                            break;
                        }
                    case 1:
                        result = cell.getRichStringCellValue().getString();
                        break;
                }
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
